@@ -15,7 +15,7 @@ from embed_video.fields import EmbedVideoField
 from PIL import Image
 
 from paperclip.settings import (PAPERCLIP_ENABLE_LINK, PAPERCLIP_ENABLE_VIDEO,
-                                PAPERCLIP_FILETYPE_MODEL, PAPERCLIP_MAX_ATTACHMENT_HEIGHT,
+                                PAPERCLIP_LICENSE_MODEL, PAPERCLIP_FILETYPE_MODEL, PAPERCLIP_MAX_ATTACHMENT_HEIGHT,
                                 PAPERCLIP_MAX_ATTACHMENT_WIDTH, PAPERCLIP_RESIZE_ATTACHMENTS_ON_UPLOAD)
 
 
@@ -37,6 +37,20 @@ class FileType(models.Model):
         return self.type
 
 
+class License(models.Model):
+
+    label = models.CharField(max_length=128, verbose_name=_("License name"), null=False, blank=False, unique=True)
+
+    def __str__(self):
+        return self.label
+
+    class Meta:
+        abstract = True
+        verbose_name = _("Attachment license")
+        verbose_name_plural = _("Attachment licenses")
+        ordering = ['label']
+
+
 class AttachmentManager(models.Manager):
     def attachments_for_object(self, obj):
         object_type = ContentType.objects.get_for_model(obj)
@@ -81,19 +95,24 @@ class Attachment(models.Model):
                                 related_name="created_attachments",
                                 verbose_name=_('Creator'),
                                 help_text=_("User that uploaded"), on_delete=models.CASCADE)
+    license = models.ForeignKey(PAPERCLIP_LICENSE_MODEL,
+                                verbose_name=_("License"),
+                                null=True,
+                                blank=True,
+                                on_delete=models.SET_NULL)
     author = models.CharField(blank=True, default='', max_length=128,
-                              db_column='auteur', verbose_name=_('Author'),
+                              verbose_name=_('Author'),
                               help_text=_("Original creator"))
     title = models.CharField(blank=True, default='', max_length=128,
-                             db_column='titre', verbose_name=_(u"Filename"),
+                             verbose_name=_("Filename"),
                              help_text=_("Renames the file"))
     legend = models.CharField(blank=True, default='', max_length=128,
-                              db_column='legende', verbose_name=_(u"Legend"),
+                              verbose_name=_("Legend"),
                               help_text=_("Details displayed"))
-    starred = models.BooleanField(default=False, db_column='marque',
-                                  verbose_name=_(u"Starred"),
+    starred = models.BooleanField(default=False,
+                                  verbose_name=_("Starred"),
                                   help_text=_("Mark as starred"))
-    is_image = models.BooleanField(editable=False, default=False, verbose_name=_(u"Is image"),
+    is_image = models.BooleanField(editable=False, default=False, verbose_name=_("Is image"),
                                    help_text=_("Is an image file"), db_index=True)
     date_insert = models.DateTimeField(editable=False, auto_now_add=True,
                                        verbose_name=_("Insertion date"))
